@@ -329,11 +329,7 @@ def find_all_parents(tree: list, target_list: list, parent_key: str = "parent_id
     def build_map(nodes):
         """递归构建节点映射表"""
         for node in nodes:
-            node_map[node[key]] = {
-                parent_key: node.get(parent_key, ''),
-                children_key: node.get(children_key, []),
-                key: node[key]
-            }
+            node_map[node[key]] = node
             if value_key and value_key not in node:
                 node[value_key] = node.get(value_key, '')
             if children_key in node and node[children_key]:
@@ -390,11 +386,7 @@ def find_all_children(tree: list, target_list: list, parent_key: str = "parent_i
     def build_map(nodes):
         """递归构建节点映射表"""
         for node in nodes:
-            node_map[node[key]] = {
-                parent_key: node.get(parent_key, ''),
-                children_key: node.get(children_key, []),
-                key: node[key]
-            }
+            node_map[node[key]] = node
             if value_key and value_key not in node:
                 node[value_key] = node.get(value_key, '')
             if children_key in node and node[children_key]:
